pub struct SemanticModel {
pub tables: HashMap<String, SymbolInfo>,
pub columns: HashMap<String, Vec<SymbolInfo>>,
pub enums: HashMap<String, SymbolInfo>,
pub errors: Vec<SemanticError>,
}Fields
tables: HashMap<String, SymbolInfo>columns: HashMap<String, Vec<SymbolInfo>>enums: HashMap<String, SymbolInfo>errors: Vec<SemanticError>Implementations
Sourceimpl SemanticModel
impl SemanticModel
pub fn new() -> Self
pub fn analyze(document: &Document) -> Self
pub fn find_symbol_at_position(&self, pos: usize) -> Option<&SymbolInfo>
Sourcepub fn find_definition_at_position(
&self,
pos: usize,
ast: &Document,
) -> Option<SymbolInfo>
pub fn find_definition_at_position( &self, pos: usize, ast: &Document, ) -> Option<SymbolInfo>
Find the definition location for a symbol at the given position Returns the target symbol info (where to jump to)
pub fn to_diagnostics(&self, content: &str) -> Vec<Diagnostic>