pub struct FormattingOptions {
pub tab_size: u32,
pub insert_spaces: bool,
pub trim_trailing_whitespace: bool,
pub insert_final_newline: bool,
pub trim_final_newlines: bool,
}Expand description
Formatting options for DBML documents
Fields
tab_size: u32Size of a tab in spaces
insert_spaces: boolPrefer spaces over tabs
trim_trailing_whitespace: boolTrim trailing whitespace on lines
insert_final_newline: boolInsert a final newline at the end of the file
trim_final_newlines: boolTrim all newlines after the final newline at the end of the file
Implementations